@@ -5,6 +5,16 @@ def current_ts(tz=pytz.utc):
     """ returns the current timestamp for the specified timezone """
     return int(datetime.datetime.now(tz).timestamp()*1000)
 
+def get_ttl(ts=current_ts(), year=0, month=0, day=0, hour=0, minute=0, return_mode='s'):
+    delta_time_minutes = (year * 525600) + (month * 43800) + (day * 1440) + (hour * 60) + minute
+    if delta_time_minutes <= 0:
+        raise Exception('At least 1 parameter is required (year, month, day, hour, minute')
+    if return_mode == 's':
+        return int(ts/1000 + delta_time_minutes*60)
+    elif return_mode == 'ms':
+        return int(ts/1000 + delta_time_minutes*60) * 1000
+    else:
+        raise Exception('return_mode param has to be s: second or ms: millisecond')
 
 def ts_to_datetime(ts, timezone):
     """ Convert timestamp (UTC) to datetime in timezone in parameters
